@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use File::Basename;
 use Config;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -158,7 +158,6 @@ my @contentwidgets = qw(
 	Entry
 	FloatEntry
 	Spinbox
-	PodText
 	Text
 	TextUndo
 	TextEditor
@@ -183,11 +182,14 @@ my %mainoptions = qw(
 	font                 gtk-font-name
 	activeBackground     tk-active-background
 	activeForeground     theme_fg_color
+	disabledBackground   tk-disabled-bg
+	disabledForeground   tk-disabled-fg
 	backPageColor        tk-through-color
 	highlightBackground  theme_bg_color
 	highlightColor			    theme_selected_bg_color
 	inactiveBackground   tk-through-color
 	insertBackground     theme_fg_color
+	linkColor            link_color
 	selectBackground     theme_selected_bg_color
 	selectForeground     theme_selected_fg_color
 	troughColor          tk-through-color
@@ -282,8 +284,6 @@ If the channel value is greater than 127 it will substract, otherwise it will ad
  alterColor('#000000', 1) returns #010101
  alterColor('#FFFFFF', 1) returns #FEFEFE
 
-=back
-
 =cut
 
 sub alterColor {
@@ -306,14 +306,10 @@ sub alterColor {
 
 =item B<applyGtkSettings>
 
-=over 4
-
 Just making life easy. Call this one and your done, unless you require adjustments.
 It calls B<initDefaults> and exports the whole bunch to xrdb.
 Exported by default.
 
-=back
-
 =cut
 
 sub applyGtkSettings {
@@ -324,14 +320,10 @@ sub applyGtkSettings {
 
 =item B<appName>(I<$name>)
 
-=over 4
-
 Sets and returns your application name. By default it is set to the basename of what is in B<$0>. Your Gtk settings
 will only be applied to your application in xrdb. You can set it to an empty string. Then it will 
 apply your Gtk settings to all your perl/Tk applications.
 
-=back
-
 =cut
 
 sub appName {
@@ -346,13 +338,9 @@ sub appName {
 
 =item B<convertColorCode>(I<'rgb(255, 0, 0)'>)
 
-=over 4
-
 Some color settings in the Gtk configuration files are in the format 'rgb(255, 255, 255)'.
 B<convertColorCode> converts these to a hex color string.
 
-=back
-
 =cut
 
 sub convertColorCode {
@@ -367,12 +355,8 @@ sub convertColorCode {
 
 =item B<decodeFont>(I<$gtkfontstring>)
 
-=over 4
-
 Converts the font string in gtk to something Tk can handle
 
-=back
-
 =cut
 
 sub decodeFont {
@@ -399,15 +383,11 @@ sub decodeFont {
 
 =item B<export2file>(I<$file>, ?I<$removeflag>?)
 
-=over 4
-
 Exports your Gtk settings to $file in a format recognized by xrdb. It looks for a section
 in the file marked by appName . "Tk::GtkSettings section\n". If it finds it it will replace this section.
 Otherwise it will append your Gtk settings to the end of the file. If $file does not yet exist it
 will create it. if $removeflag is true it will not export but remove the section from $file.
 
-=back
-
 =cut
 
 sub export2file {
@@ -451,12 +431,8 @@ sub export2file {
 
 =item B<export2Xdefaults>(?I<$removeflag>?)
 
-=over 4
-
 Same as B<export2file>, however the file is always '~/.Xdefaults'.
 
-=back
-
 =cut
 
 sub export2Xdefaults {
@@ -465,12 +441,8 @@ sub export2Xdefaults {
 
 =item B<export2Xresources>(?I<$removeflag>?)
 
-=over 4
-
 Same as B<export2file>, however the file is always '~/.Xresources'.
 
-=back
-
 =cut
 
 sub export2Xresources {
@@ -479,12 +451,8 @@ sub export2Xresources {
 
 =item B<export2xrdb>
 
-=over 4
-
 exports your Gtk settings directly to the xrdb database.
 
-=back
-
 =cut
 
 sub export2xrdb {
@@ -500,12 +468,8 @@ sub export2xrdb {
 
 =item B<generateOutput>
 
-=over 4
-
 Generates the output used by the export functions. Returns a string.
 
-=back
-
 =cut
 
 sub generateOutput {
@@ -540,13 +504,9 @@ sub generateOutput {
 
 =item B<groupAdd>(I<$groupname>, I<\@members>, I<\%options>)
 
-=over 4
-
 Adds $groupname to the groups hash. If @members or %options are not specified, 
 it will leave them empty.
 
-=back
-
 =cut
 
 sub groupAdd {
@@ -566,12 +526,8 @@ sub groupAdd {
 
 =item B<groupAll>
 
-=over 4
-
 Returns a list of all available groups.
 
-=back
-
 =cut
 
 sub groupAll {
@@ -580,12 +536,8 @@ sub groupAll {
 
 =item B<groupDelete>(I<$groupname>)
 
-=over 4
-
 Removes $groupsname from the groups hash. You cannot delete the 'main' group.
 
-=back
-
 =cut
 
 sub groupDelete {
@@ -602,12 +554,8 @@ sub groupDelete {
 
 =item B<groupExists>(I<$groupname>)
 
-=over 4
-
 Returns true if $groupname is available.
 
-=back
-
 =cut
 
 sub groupExists {
@@ -625,13 +573,9 @@ sub groupExists {
 
 =item B<groupMembers>(I<$groupname>)
 
-=over 4
-
 Returns the list of existing members of $groupname. It will return an empty list
 if $groupname equals 'main'.
 
-=back
-
 =cut
 
 sub groupMembers {
@@ -648,12 +592,8 @@ sub groupMembers {
 
 =item B<groupMembersAdd>(I<$groupname>, I<@newmembers>)
 
-=over 4
-
 Adds new members to $groupname. You cannot add members to the 'main' group.
 
-=back
-
 =cut
 
 sub groupMembersAdd {
@@ -670,12 +610,8 @@ sub groupMembersAdd {
 
 =item B<groupMembersReplace>(I<$groupname>, I<@members>)
 
-=over 4
-
 Replaces the list of members in $groupsname by @members. You cannot modify the members list of the 'main' group.
 
-=back
-
 =cut
 
 sub groupMembersReplace {
@@ -692,13 +628,9 @@ sub groupMembersReplace {
 
 =item B<groupOption>(I<$groupname>, I<$option>, ?I<$value>?)
 
-=over 4
-
 Sets and returns the value of $option in $groupname. $value should be a corresponding key from
 the Gtk hash. If that key is not found, it assumes a direct value.
 
-=back
-
 =cut
 
 sub groupOption {
@@ -719,12 +651,8 @@ sub groupOption {
 
 =item B<groupOptionAll>(I<$groupname>)
 
-=over 4
-
 Returns a list of all available options in $groupname.
 
-=back
-
 =cut
 
 sub groupOptionAll {
@@ -737,12 +665,8 @@ sub groupOptionAll {
 
 =item B<groupOptionDelete>(I<$groupname>, I<$option>)
 
-=over 4
-
 Removes $option from $groupname
 
-=back
-
 =cut
 
 sub groupOptionDelete {
@@ -759,12 +683,8 @@ sub groupOptionDelete {
 
 =item B<gtkKey>(I<$key>, ?I<$value>?)
 
-=over 4
-
 Sets and returns the value of $key in the Gtk hash
 
-=back
-
 =cut
 
 sub gtkKey {
@@ -781,12 +701,8 @@ sub gtkKey {
 
 =item B<gtkKeyAll>
 
-=over 4
-
 Returns a list of all available keys in the Gtk hash.
 
-=back
-
 =cut
 
 sub gtkKeyAll {
@@ -796,12 +712,8 @@ sub gtkKeyAll {
 
 =item B<gtkKeyDelete>(I<$key>)
 
-=over 4
-
 Delets $key from the Gtk hash.
 
-=back
-
 =cut
 
 sub gtkKeyDelete {
@@ -816,12 +728,8 @@ sub gtkKeyDelete {
 
 =item B<hex2rgb>(I<$hex_color>)
 
-=over 4
-
 Returns and array with the decimal values of red, green and blue.
 
-=back
-
 =cut
 
 sub hex2rgb {
@@ -838,12 +746,8 @@ sub hex2rgb {
 
 =item B<hexstring>(I<$num>)
 
-=over 4
-
 Return the hexadecimal representation of $num in a two character string.
 
-=back
-
 =cut
 
 sub hexstring {
@@ -855,12 +759,8 @@ sub hexstring {
 
 =item B<initDefaults>
 
-=over 4
-
 Initializes some sensible defaults. Also does a full reset and loads Gtk configuration files.
 
-=back
-
 =cut
 
 sub initDefaults {
@@ -869,6 +769,8 @@ sub initDefaults {
 	loadGtkInfo;
 	gtkKey('tk-active-background', alterColor(gtkKey('theme_bg_color'), 30));
 	gtkKey('tk-through-color', alterColor(gtkKey('theme_bg_color'), 30));
+	gtkKey('tk-disabled-bg', alterColor(gtkKey('theme_bg_color'), 30));
+	gtkKey('tk-disabled-fg', alterColor(gtkKey('theme_fg_color'), 90));
 
 	for (keys %mainoptions) {
 		groupOption('main', $_, $mainoptions{$_})
@@ -888,12 +790,8 @@ sub initDefaults {
 
 =item B<loadGtkInfo>
 
-=over 4
-
 Empties the Gtk hash and (re)loads the Gtk configuration files.
 
-=back
-
 =cut
 
 sub loadGtkInfo {
@@ -939,12 +837,8 @@ sub loadGtkInfo {
 
 =item B<platformPermitted>
 
-=over 4
-
 Returns true if you are not on Windows or Mac.
 
-=back
-
 =cut
 
 sub platformPermitted {
@@ -955,12 +849,8 @@ sub platformPermitted {
 
 =item B<removeFromfile>(I<$file>)
 
-=over 4
-
 Same as export2file($file, 1)
 
-=back
-
 =cut
 
 sub removeFromfile {
@@ -970,12 +860,8 @@ sub removeFromfile {
 
 =item B<removeFromXdefaults>
 
-=over 4
-
 Same as export2Xdefaults(1)
 
-=back
-
 =cut
 
 sub removeFromXdefaults {
@@ -984,12 +870,8 @@ sub removeFromXdefaults {
 
 =item B<removeFromXresources>
 
-=over 4
-
 Same as export2Xresources(1)
 
-=back
-
 =cut
 
 sub removeFromXresources {
@@ -998,12 +880,8 @@ sub removeFromXresources {
 
 =item B<removeFromxrdb>
 
-=over 4
-
 Removes all the settings previously defined from the xrdb database
 
-=back
-
 =cut
 
 sub removeFromxrdb {
@@ -1019,13 +897,9 @@ sub removeFromxrdb {
 
 =item B<resetAll>
 
-=over 4
-
 Removes all groups and options. The group 'main' will remain, but all its options are also deleted.
 This does not affect the Gtk hash.
 
-=back
-
 =cut
 
 sub resetAll {
@@ -1036,12 +910,8 @@ sub resetAll {
 
 =item B<rgb2hex>(I<$red>, I<$green>, I<$blue>)
 
-=over 4
-
 Converts the decimval values $red, $green and $blue into a hex color string.
 
-=back
-
 =cut
 
 sub rgb2hex {
@@ -1070,7 +940,7 @@ sub _truncate {
 
 Copyright 2022 - 2023 by Hans Jeuken
 
-Same as Perl, in your option.
+Same as Perl
 
 =head1 AUTHOR
 
